CompactLen

Trait CompactLen 

pub trait CompactLen<T> {
    // Required method
    fn compact_len(val: &T) -> usize;
}
Something that can return the compact encoded length for a given value.

Required Methods

fn compact_len(val: &T) -> usize

Returns the compact encoded length for the given value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors