WrapperTypeDecode

Trait WrapperTypeDecode 

pub trait WrapperTypeDecode: Sized {
    type Wrapped: Into<Self>;
}
A marker trait for types that can be created solely from other decodable types.

The decoding of such type is assumed to be the same as the wrapped type.

Required Associated Types

type Wrapped: Into<Self>

A wrapped type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> WrapperTypeDecode for Arc<T>

Available on target_has_atomic=ptr only.
Source

impl<T> WrapperTypeDecode for Box<T>

Source

impl<T> WrapperTypeDecode for Rc<T>

Implementors