pub trait WrapperTypeEncode: Deref { }Expand description
A marker trait for types that wrap other encodable type.
Such types should not carry any additional information that would require to be encoded, because the encoding is assumed to be the same as the wrapped type.
The wrapped type that is referred to is the Deref::Target.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".